@@ -63,7 +63,7 @@ struct SpriteInfo {
 	bool forcereopen;
 
 	void writetobuffer(U8 *buffer, int grfcontversion);
-	void readfromfile(const char *action, int grfcontversion, FILE *grf);
+	void readfromfile(const char *action, int grfcontversion, FILE *grf, int spriteno);
 	static int Size(int grfcontversion) { return grfcontversion == 2 ? 10 : 8; }
 };
 
@@ -71,7 +71,7 @@ class spriteinfowriter {
 	public:
 	~spriteinfowriter() {}
 	virtual void addsprite(bool /* first */, const char * /* filename */, int /* y */, int /*x*/, SpriteInfo /*info*/) { };
-	virtual void adddata(U16 /*size*/, U8 * /*data*/) { };
+	virtual void adddata(uint /*size*/, U8 * /*data*/) { };
 };
 
 class spritestorage {
